# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-10 14:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('example', '0005_auto_20171107_1628'),
    ]

    operations = [
        migrations.AlterField(
            model_name='myuser',
            name='customer_category',
            field=models.CharField(blank=True, choices=[('QUALITY_PARTNER', 'quality partner'), ('DEALER', 'dealer'), ('ARCHITECT_PLANNER', 'architect/planner'), ('HOUSING_SOCIETY', 'housing society'), ('PRIVATE_CUSTOMER', 'private customer'), ('OTHERS', 'others')], max_length=200, null=True, verbose_name='customer category'),
        ),
        migrations.AlterField(
            model_name='myuser',
            name='title',
            field=models.CharField(blank=True, choices=[('MR', 'Mr.'), ('MRS', 'Mrs.')], max_length=20, null=True, verbose_name='title'),
        ),
    ]
