# Generated by Django 2.0.1 on 2018-02-08 22:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('example', '0009_auto_20180208_2347'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='myuser',
            name='customer_category',
        ),
        migrations.RemoveField(
            model_name='myuser',
            name='um_id',
        ),
        migrations.AlterField(
            model_name='myuser',
            name='customer_name',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='customer name'),
        ),
        migrations.AlterField(
            model_name='myuser',
            name='email',
            field=models.EmailField(blank=True, max_length=254, verbose_name='email address'),
        ),
        migrations.AlterField(
            model_name='myuser',
            name='first_name',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='first name'),
        ),
        migrations.AlterField(
            model_name='myuser',
            name='language',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='language'),
        ),
        migrations.AlterField(
            model_name='myuser',
            name='last_name',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='last name'),
        ),
        migrations.AlterField(
            model_name='myuser',
            name='password',
            field=models.CharField(blank=True, max_length=128, null=True, verbose_name='password'),
        ),
        migrations.AlterField(
            model_name='myuser',
            name='title',
            field=models.CharField(blank=True, choices=[('MR', 'Mr.'), ('MRS', 'Mrs.')], max_length=255, null=True, verbose_name='title'),
        ),
    ]
